@@ -3,7 +3,7 @@ from interflow.sample_data import *
 from interflow.reader import *
 
 
-class MyTestCase(unittest.TestCase):
+class TestSampleData(unittest.TestCase):
     """Conduct tests for functions of sample_data.py."""
 
     def test_convert_kwh_bbtu(self):
@@ -72,8 +72,8 @@ class MyTestCase(unittest.TestCase):
                             'AGR_crop_reclaimed_wastewater_import_mgd_to_CMP_total_total_total_total_mgd_fraction',
                             'AGR_golf_fresh_surfacewater_withdrawal_mgd_to_CMP_total_total_total_total_mgd_fraction',
                             'AGR_golf_fresh_groundwater_withdrawal_mgd_to_CMP_total_total_total_total_mgd_fraction',
-                            'AGR_golf_reclaimed_wastewater_import_mgd_to_CMP_total_total_total_total_mgd_fraction',
-                            'AGR_crop_ibt_total_import_mgd_to_CMP_total_total_total_total_mgd_fraction']
+                            'AGR_golf_reclaimed_wastewater_import_mgd_to_CMP_total_total_total_total_mgd_fraction'
+                            ]
         self.assertEqual(output_columns, expected_columns)
 
         # test that there are 3,142 counties included
